@@ -54,6 +54,10 @@ class ParallelTextRow:
     def ref(self) -> Any:
         return self.target_refs[0] if len(self.source_refs) == 0 else self.source_refs[0]
 
+    @property
+    def refs(self) -> Sequence[Any]:
+        return self.target_refs if len(self.source_refs) == 0 else self.source_refs
+
     @property
     def source_text(self) -> str:
         return " ".join(self.source_segment)
