@@ -2,7 +2,6 @@ from pathlib import Path
 from typing import List, Optional
 
 from ..scripture.verse_ref import Versification, VersificationType
-from ..tokenization.tokenizer import Tokenizer
 from ..utils.typeshed import StrPath
 from .scripture_text_corpus import ScriptureTextCorpus
 from .usfm_file_text import UsfmFileText
@@ -12,7 +11,6 @@ from .usfm_stylesheet import UsfmStylesheet
 class UsfmFileTextCorpus(ScriptureTextCorpus):
     def __init__(
         self,
-        word_tokenizer: Tokenizer[str, int, str],
         stylesheet_filename: StrPath,
         encoding: str,
         project_dir: StrPath,
@@ -25,7 +23,5 @@ class UsfmFileTextCorpus(ScriptureTextCorpus):
         stylesheet = UsfmStylesheet(stylesheet_filename)
         texts: List[UsfmFileText] = []
         for sfm_filename in Path(project_dir).glob(file_pattern):
-            texts.append(
-                UsfmFileText(word_tokenizer, stylesheet, encoding, sfm_filename, versification, include_markers)
-            )
-        super().__init__(word_tokenizer, versification, texts)
+            texts.append(UsfmFileText(stylesheet, encoding, sfm_filename, versification, include_markers))
+        super().__init__(versification, texts)
