@@ -1,3 +1,4 @@
+from .corpus_ops import align_corpus, translate_corpus
 from .edit_operation import EditOperation
 from .hmm_word_alignment_model import HmmWordAlignmentModel
 from .ibm1_word_alignment_model import Ibm1WordAlignmentModel
@@ -8,7 +9,7 @@ from .symmetrized_word_aligner import SymmetrizedWordAligner
 from .symmetrized_word_alignment_model import SymmetrizedWordAlignmentModel
 from .symmetrized_word_alignment_model_trainer import SymmetrizedWordAlignmentModelTrainer
 from .trainer import Trainer, TrainStats
-from .translation_engine import TranslationEngine, translate_corpus
+from .translation_engine import TranslationEngine
 from .translation_model import TranslationModel
 from .translation_result import TranslationResult
 from .translation_result_builder import TranslationResultBuilder
@@ -37,5 +38,6 @@ __all__ = [
     "WordAligner",
     "WordAlignmentMatrix",
     "WordAlignmentModel",
+    "align_corpus",
     "translate_corpus",
 ]
