@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import heapq
 from types import TracebackType
-from typing import Any, Dict, Iterable, List, Optional, Sequence, Set, Tuple, Type, Union, cast, overload
+from typing import Any, Dict, Iterable, List, Optional, Sequence, Set, Tuple, Type, cast
 
 import numpy as np
 import tensorflow as tf
@@ -112,37 +112,25 @@ class OpenNmtEngine(TranslationEngine):
     def restore(self) -> None:
         self._checkpoint_model, self._config = self._model.restore_checkpoint()
 
-    @overload
     def translate(self, segment: Sequence[str]) -> TranslationResult:
-        ...
+        return next(iter(self.translate_batch([segment])))
 
-    @overload
-    def translate(self, segment: Sequence[str], n: int) -> List[TranslationResult]:
-        ...
-
-    def translate(
-        self, segment: Sequence[str], n: Optional[int] = None
-    ) -> Union[TranslationResult, List[TranslationResult]]:
-        if n is None:
-            return next(iter(self.translate_batch([segment])))
-        return next(iter(self.translate_batch([segment], n)))
-
-    @overload
-    def translate_batch(self, segments: Iterable[Sequence[str]]) -> Iterable[TranslationResult]:
-        ...
-
-    @overload
-    def translate_batch(self, segments: Iterable[Sequence[str]], n: int) -> Iterable[List[TranslationResult]]:
-        ...
+    def translate_n(self, n: int, segment: Sequence[str]) -> List[TranslationResult]:
+        return next(iter(self.translate_n_batch(n, [segment])))
 
     def translate_batch(
-        self, segments: Iterable[Sequence[str]], n: Optional[int] = None
-    ) -> Union[Iterable[TranslationResult], Iterable[List[TranslationResult]]]:
+        self, segments: Iterable[Sequence[str]], batch_size: Optional[int] = None
+    ) -> Iterable[TranslationResult]:
+        return (results[0] for results in self.translate_n_batch(1, segments, batch_size))
+
+    def translate_n_batch(
+        self, n: int, segments: Iterable[Sequence[str]], batch_size: Optional[int] = None
+    ) -> Iterable[List[TranslationResult]]:
         infer_config = self._config["infer"]
         features = (" ".join(segment) for segment in segments)
         dataset = self._make_inference_dataset(
             [features],
-            infer_config["batch_size"],
+            infer_config["batch_size"] if batch_size is None else min(infer_config["batch_size"], batch_size),
             length_bucket_width=infer_config["length_bucket_width"],
             prefetch_buffer_size=infer_config.get("prefetch_buffer_size"),
         )
@@ -156,8 +144,7 @@ class OpenNmtEngine(TranslationEngine):
         queued_results: Dict[int, List[TranslationResult]] = {}
         next_index = 0
         heap: List[int] = []
-        for source in dataset:
-            source: dict = source
+        for source in cast(Iterable[dict], dataset):
             predictions = self._infer_fn(source)
             predictions["src_tokens"] = source["tokens"]
             predictions["src_length"] = source["length"]
@@ -197,7 +184,7 @@ class OpenNmtEngine(TranslationEngine):
                 while len(heap) > 0 and heap[0] == next_index:
                     i = heapq.heappop(heap)
                     result = queued_results.pop(i)
-                    yield result if n is not None else result[0]
+                    yield result
                     next_index += 1
 
     def __enter__(self) -> OpenNmtEngine:
